
# Slot: chapter


chapter of a book

URI: [biolink:chapter](https://w3id.org/biolink/vocab/chapter)


## Domain and Range

[BookChapter](BookChapter.md) &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children


## Used by

 * [BookChapter](BookChapter.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | WIKIDATA:Q1980247 |

